# Мотор

OpenMV имеет IO ввода-вывода и может управлять различными двигателями.

## шаговый двигатель

### Что такое шаговый двигатель

Шаговый двигатель — это двигатель с разомкнутым контуром управления,
преобразующий электрические импульсные сигналы в угловое или линейное
перемещение. Он является основным исполнительным элементом в современных
цифровых системах программного управления и широко применяется.

Например, 3D-принтеры и роботизированные руки.

### Плата драйвера шагового двигателя

Многие чипы и модули могут управлять шаговыми двигателями. Мы используем очень
простой модуль EasyDriver.

Проще говоря, направление контролируется параметром dir. Если подать импульс на
шаг, двигатель переместится на один шаг.

![](/assets/06-07-001.jpg)

### Соединять

![](/assets/06-07-002.jpg)

## Установить модуль

[Код модуля находится по этой
ссылке](http://book.openmv.cc/module/write-module-motor.html)

Сохраните код этого класса как файл stepper.py и поместите его в корневой
каталог OpenMV.

## код

```python
# 步进电机控制 - By: 小智智- 周日 4月 2 2017

from pyb import Pin

from stepper import Stepper

import time

step_pin = Pin('P0')
dir_pin = Pin('P1')

my_stepper = Stepper(step_pin,dir_pin)

print("relative angle move test begin:", my_stepper.read_pos())
my_stepper.rel_angle(180)#相对角度控制
print("relative angle move test end:", my_stepper.read_pos())

time.sleep_ms(1000)

print("steps angle move test end:", my_stepper.read_pos())
my_stepper.steps(-400)#步进脉冲控制
print("steps angle move test end:", my_stepper.read_pos())

time.sleep_ms(1000)

print("absolute angle move test begin:", my_stepper.read_pos())
my_stepper.abs_angle(0)#绝对角度控制
print("absolute angle move test end:", my_stepper.read_pos())

time.sleep_ms(1000)
```

## двигатель постоянного тока

#### Учебное пособие 26. Версия расширения двигателя управляет двигателем постоянного тока: [https://singtown.com/video](https://singtown.com/video)

### Что такое двигатель постоянного тока

Скорость двигателя постоянного тока прямо пропорциональна напряжению.

### Плата водителя

Многие платы драйверов могут управлять двигателями постоянного тока, здесь мы
используем двойной H-мост TB6612FNG.

![](/assets/06-07-003.jpg)

### Соединять

![](/assets/06-07-004.jpg)

### код

```python
待添加
```

## рулевой механизм

OpenMV2 имеет два сервопина: P7 и P8

OpenMV3 имеет три контакта сервопривода: P7, P8, P9

### Соединять

![](/assets/06-07-005.jpg)

### Проверьте источник питания

Сервопривод является сильноточным устройством и должен использовать внешний
источник питания (стабилизированный источник питания, литиевая батарея...)！

### код

```python
# Servo Control Example
#
# This example shows how to use your OpenMV Cam to control servos.

import time
from pyb import Servo

s1 = Servo(1) # P7
s2 = Servo(2) # P8
#s3 = Servo(3) # P9 Only for OpenMV3 M7
while(True):
    for i in range(-90,90):
        s1.angle(i)
        s2.angle(i)
        time.sleep_ms(10)
    for i in range(90,-90):
        s1.angle(i)
        s2.angle(i)
        time.sleep_ms(10)
```

## PCA9685 соединяет несколько сервоприводов

Детская ссылка:
[https://singtown.com/product/49277](https://singtown.com/product/49277)

#### Видеоурок 25 — pca9685 управляет несколькими сервоприводами: [https://singtown.com/learn/50057/](https://singtown.com/learn/50057/)



Модуль PCA9685, используя всего 2 контакта (протокол I2C), может управлять 16
каналами PWM, то есть 16 сервоприводами или 16 светодиодными лампами. Вы даже
можете подключить 62 модуля и при этом использовать только 2 контакта для
управления 992 PWM!

Соединять

![](/assets/06-07-006-01.jpg)

код

![](/assets/06-07-007.jpg)

Нажмите, чтобы запустить

